==> sqlstreamstore-browser-0.1.78.tgz: package/src/stream-store/actions.ts <==
import { Action, Location } from 'history';
import { ReplaySubject } from 'rxjs';
import { createAction } from './../reactive';
import { HttpRequest, HttpResponse } from './../types';
import { history, http } from './../utils';

type Actions = {
    [P in keyof typeof http]: {
        request: ReplaySubject<HttpRequest>;
        response: ReplaySubject<HttpResponse>;
    }
};

type HttpVerb = keyof typeof http;

const verbs: HttpVerb[] = Object.keys(http) as HttpVerb[];

const actions: Actions = verbs.reduce(
    (akk, verb: keyof typeof http) => ({
        ...akk,
        [verb]: {
            request: createAction(),
            response: createAction(),
        },
    }),
    // tslint:disable-next-line:no-object-literal-type-assertion
    {} as Actions,
);

const urlParamName = 'storeUrl';

verbs.forEach(verb =>
    actions[verb].request
        .flatMap(request => http[verb](request))
        .subscribe(response => actions[verb].response.next(response)),
);

actions.get.response.subscribe(({ url }) => {
    const currentUrl = window.location.href.split('?')[0];
    history.push(`${currentUrl}?${urlParamName}=${atob(url)}`);
});

history.listen(
    (location: Location, action: Action): void => {
        if (action !== 'POP') {
            return;
        }

        const urlParams = new URLSearchParams(location.search);
        const storeUrl = urlParams.get(urlParamName);

        if (storeUrl != null) {
            try {
                console.log('history')
                const url = btoa(storeUrl);

                actions.get.request.next({
                    headers: {},
                    link: { href: url },
                });
            } catch (e) {
                console.error('btoa failed', e);
            }

        }
    },
);

export default actions;

==> sqlstreamstore-browser-0.1.79.tgz: package/src/stream-store/actions.ts <==
import { Action, Location } from 'history';
import { ReplaySubject } from 'rxjs';
import { createAction } from './../reactive';
import { HttpRequest, HttpResponse } from './../types';
import { history, http } from './../utils';

type Actions = {
    [P in keyof typeof http]: {
        request: ReplaySubject<HttpRequest>;
        response: ReplaySubject<HttpResponse>;
    }
};

type HttpVerb = keyof typeof http;

const verbs: HttpVerb[] = Object.keys(http) as HttpVerb[];

const actions: Actions = verbs.reduce(
    (akk, verb: keyof typeof http) => ({
        ...akk,
        [verb]: {
            request: createAction(),
            response: createAction(),
        },
    }),
    // tslint:disable-next-line:no-object-literal-type-assertion
    {} as Actions,
);

const urlParamName = 'storeUrl';

verbs.forEach(verb =>
    actions[verb].request
        .flatMap(request => http[verb](request))
        .subscribe(response => actions[verb].response.next(response)),
);

actions.get.response.subscribe(({ url }) => {
    const currentUrl = window.location.href.split('?')[0];
    history.push(`${currentUrl}?${urlParamName}=${btoa(url)}`);
});

history.listen(
    (location: Location, action: Action): void => {
        if (action !== 'POP') {
            return;
        }

        const urlParams = new URLSearchParams(location.search);
        const storeUrl = urlParams.get(urlParamName);

        if (storeUrl != null) {
            try {
                console.log('history')
                const url = atob(storeUrl);

                actions.get.request.next({
                    headers: {},
                    link: { href: url },
                });
            } catch (e) {
                console.error('btoa failed', e);
            }

        }
    },
);

export default actions;
